<?php
namespace FormAlert;

use Exception;

if (!defined('ABSPATH')) {
  exit;
}

class Class_admin
{
  /**
   * Instance of the database handler.
   *
   * @var Class_database
   */
  private $db;

  /**
   * Instance of the API handler.
   *
   * @var Class_api
   */
  private $api;

  /**
   * Instance of the admin handler.
   *
   * @var Class_settings
   */
  private $settings;

  /**
   * Initialize the plugin.
   */
  public function __construct()
  {
    $this->init_dependencies();
  }

  /**
   * Initialize plugin dependencies.
   */
  private function init_dependencies()
  {
    $this->db = new Class_database();
    $this->db->validate_tables();
    $this->api = new Class_api($this->db);
    $this->settings = new Class_settings();
  }

  /**
   * Plugin activation.
   */
  public function activate()
  {
    try {
      $this->db->create_tables();
    } catch (Exception $e) {
      deactivate_plugins(plugin_basename(__FILE__));
      wp_die(
        "Failed to create required database tables. Error: " .
        esc_html($e->getMessage())
      );
    }

    flush_rewrite_rules();
  }

  /**
   * Plugin deactivation.
   */
  public function deactivate()
  {
    flush_rewrite_rules();
  }
}
