document.addEventListener('DOMContentLoaded', function () {
	const form = document.getElementById('api-key-form');

	const delete_forms = document.querySelectorAll('.delete-form');

	if (!form) {
		console.error('Form, response container or submit button not found');
		return;
	}

	form.addEventListener('submit', async function (e) {
		e.preventDefault();
		const submit_button = form.querySelector('#submit_api_key');
		const response_container = form.querySelector('#response');

		if (!submit_button || !response_container) {
			console.error('Submit button or response container not found');
			return;
		}

		submit_button.disabled = true;

		response_container.innerHTML = 'Saving...';

		const formData = new FormData(e.currentTarget);

		const name = formData.get('name');
		const api_key = formData.get('api_key');

		if (!name || !api_key) {
			response_container.innerHTML = 'Please fill in all fields';
			return;
		}

		const nonce = formData.get('form_alert_create_nonce');

		if (!nonce) {
			response_container.innerHTML = 'Invalid nonce';
			return;
		}

		const api_path = '/wp-json/form-alert/v1/keys';

		const res = await fetch(api_path, {
			method: 'POST',
			headers: {
				'Content-Type': 'application/json',
				'X-WP-Nonce': nonce,
			},
			credentials: 'same-origin',
			body: JSON.stringify({
				name,
				api_key,
			}),
		});

		if (!res.ok) {
			response_container.innerHTML = await res.text();
			submit_button.disabled = false;
			return;
		}

		response_container.innerHTML = await res.text();
		submit_button.disabled = false;
		form.reset();

		window.location.reload();
	});

	delete_forms.forEach((form) => {
		form.addEventListener('submit', async function (e) {
			e.preventDefault();
			const submit_button = form.querySelector('.delete_api_key_button');
			submit_button.disabled = true;

			const formData = new FormData(e.currentTarget);

			const id = formData.get('id');

			const nonce = formData.get('form_alert_delete_nonce');

			if (!nonce) {
				return;
			}

			const api_path = `/wp-json/form-alert/v1/keys/${id}`;

			const res = await fetch(api_path, {
				method: 'DELETE',
				headers: {
					'Content-Type': 'application/json',
					'X-WP-Nonce': nonce,
				},
				credentials: 'same-origin',
			});

			if (!res.ok) {
				submit_button.disabled = false;
				return;
			}

			window.location.reload();
		});
	});
});
