<?php
/**
 * Plugin Name: Form Alert
 * Description: Build a form with Gutenberg that can send alerts with your Form Alert API key.
 * Requires at least: 6.5
 * Requires PHP: 7.0
 * Version: 0.1.1
 * Author: Devhuset AS
 * Author URI: https://devhuset.no
 * License: GPL-2.0-or-later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: form-alert
 *
 * @package form-alert
 */

namespace FormAlert;

if (!defined('ABSPATH')) {
    exit;
}

define('FORM_ALERT_VERSION', '0.1.1');
define('FORM_ALERT_DIR', plugin_dir_path(__FILE__));
define('FORM_ALERT_URL', plugin_dir_url(__FILE__));
define('FORM_ALERT_BASENAME', plugin_basename(__FILE__));
define('FORM_ALERT_RELATIVE_PLUGIN_DIR', dirname(plugin_basename(__FILE__)));
define('FORM_ALERT_RELATIVE_PLUGIN_FILE', plugin_basename(__FILE__));

require FORM_ALERT_DIR . 'update.php';

/**
 * Autoloader function to dynamically load classes based on their namespace and file name.
 */
spl_autoload_register(function ($class) {
    $prefix = 'FormAlert\\';
    $len = strlen($prefix);

    if (strncmp($prefix, $class, $len) !== 0) {
        return;
    }

    $relativeClass = substr($class, $len);

    $file = FORM_ALERT_DIR . 'admin/' . str_replace('\\', '/', $relativeClass) . '.php';

    if (file_exists($file)) {
        require $file;
    } else {
        error_log('File not found');
    }
});


/**
 * Main plugin class.
 */
class Plugin
{

    /**
     * Initialize the plugin.
     *
     * @return void
     */
    public static function init()
    {
        add_action('init', [self::class, 'register_blocks']);
        add_filter('block_categories_all', [self::class, 'register_categories'], 10, 2);
    }

    /**
     * Registers Gutenberg blocks.
     *
     * @return void
     */
    public static function register_blocks()
    {
        if (function_exists('wp_register_block_types_from_metadata_collection')) {
            wp_register_block_types_from_metadata_collection(__DIR__ . '/build', __DIR__ . '/build/blocks-manifest.php');
        } else {
            if (function_exists('wp_register_block_metadata_collection')) {
                wp_register_block_metadata_collection(__DIR__ . '/build', __DIR__ . '/build/blocks-manifest.php');
            }
            $manifest_data = require __DIR__ . '/build/blocks-manifest.php';
            foreach (array_keys($manifest_data) as $block_type) {
                register_block_type(__DIR__ . "/build/{$block_type}");
            }
        }
    }

    /**
     * Register custom block categories.
     *
     * @param array $categories Existing categories.
     * @return array Modified categories.
     */
    public static function register_categories($categories)
    {
        return array_merge(
            $categories,
            [
                [
                    'slug' => 'form-alert',
                    'title' => __('Form Alert', 'form-alert'),
                    'icon' => 'wordpress',
                ],
            ]
        );
    }
}

register_activation_hook(__FILE__, function () {
    require_once FORM_ALERT_DIR . 'admin/Class_admin.php';
    $admin = new \FormAlert\Class_admin();
    $admin->activate();
});

register_deactivation_hook(__FILE__, function () {
    require_once FORM_ALERT_DIR . 'admin/Class_admin.php';
    $admin = new \FormAlert\Class_admin();
    $admin->deactivate();
});

// Initialize the plugin.
Plugin::init();


// Initialize admin classes on admin pages.
new \FormAlert\Class_admin();
